@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: xss-sanitize
 version: 0.3.5.6
-id: xss-sanitize-0.3.5.6-b3b679ace14b1ead6abf3b67e5cfe55e
-key: xsssa_7U2g5IFmGbeEjvDVljaKqM
+id: xss-sanitize-0.3.5.6-f78b5b03aa1efe6d65b9961065a15c78
+key: xsssa_JdGY8fSYBM7LAdXrSOFQKS
 license: BSD3
 maintainer: Greg Weber <greg@gregweber.info>
 stability: Stable
@@ -21,15 +21,15 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/xss-sanitize-0.3.5.6
 library-dirs: /usr/lib/ghc-7.10.3/site-local/xss-sanitize-0.3.5.6
 data-dir: /usr/share/arm-linux-ghc-7.10.3/xss-sanitize-0.3.5.6
-hs-libraries: HSxss-sanitize-0.3.5.6-7U2g5IFmGbeEjvDVljaKqM
+hs-libraries: HSxss-sanitize-0.3.5.6-JdGY8fSYBM7LAdXrSOFQKS
 depends:
-    attoparsec-0.13.0.1-5ea5fcb358e0d896b98f3d37ebae8a45
+    attoparsec-0.13.0.1-522c252ad233781393fab28c8daf023a
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
-    css-text-0.1.2.1-d1e175085ae55e4b9482a244b4d6aeb3
-    network-uri-2.6.0.3-27316eb865f3b3562ae77903534d67a4
-    tagsoup-0.13.8-ae67a6a9bc7b71798dd8f975b70085f0
-    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
+    css-text-0.1.2.1-5f08c8634ff151127fcfba990f98863f
+    network-uri-2.6.1.0-0e39aca8530572505c01ef548c540bd6
+    tagsoup-0.13.9-61f7129b459feb0b7d9b7f0c4b3300d3
+    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
     utf8-string-1.0.1.1-55be01444fdc59e978af349d80596373
 haddock-interfaces: /usr/share/doc/haskell-xss-sanitize/html/xss-sanitize.haddock
 haddock-html: /usr/share/doc/haskell-xss-sanitize/html
